use strict;
use warnings;
use blib;

use Test::More tests => 11;

BEGIN {
    use_ok('LMAP::CID2SPF', qw(cid2spf));
}

my $c2s = new LMAP::CID2SPF();

ok(defined $c2s, 'Created an object');
isa_ok($c2s, 'LMAP::CID2SPF');

# Here are the CIDs and SPF entries that are expected:
my @tests = (
    { 'cid' => "<ep xmlns='http://ms.net/1' testing='true'><out><noMailServers/></out></ep>",
      'spf' => "v=spf1 ?all" },
    { 'cid' => "<ep xmlns='http://ms.net/1'><out><noMailServers/></out></ep>",
      'spf' => "v=spf1 -all" },
    { 'cid' => "<ep xmlns='http://ms.net/1' testing='true'><out><m><mx/><a>213.199.128.160</a><a>131.107.3.117</a><a>131.107.3.100</a></m></out></ep>",
      'spf' => "v=spf1 mx ip4:213.199.128.160 ip4:131.107.3.117 ip4:131.107.3.100 ?all" },
    { 'cid' => "<ep xmlns='http://ms.net/1' testing='true'><out><m><indirect>list1._ep.hotmail.com</indirect><indirect>list2._ep.hotmail.com</indirect><indirect>list3._ep.hotmail.com</indirect></m></out></ep>",
      'spf' => "v=spf1 include:_ep.list1._ep.hotmail.com include:_ep.list2._ep.hotmail.com include:_ep.list3._ep.hotmail.com ?all" },
);

foreach my $test (@tests) {
    $c2s->cid($test->{'cid'});
    my $spf = $c2s->convert();
    is($spf, $test->{'spf'}, 'Successful conversion with OO');
}

foreach my $test (@tests) {
    my $spf = cid2spf($test->{'cid'});
    is($spf, $test->{'spf'}, 'Successful conversion with cid2spf');
}


